@@ -14,8 +14,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# This example creates a standard shopping campaign, a shopping product
-# ad group and a shopping product ad.
+# This example creates a standard shopping campaign, a shopping product ad group
+# and a shopping product ad.
 #
 # Prerequisite: You need to have access to a Merchant Center account. You can
 # find instructions to create a Merchant Center account here:
@@ -70,11 +70,11 @@ use Data::Uniqid qw(uniqid);
 #
 # Running the example with -h will print the command line usage.
 my $customer_id                  = "INSERT_CUSTOMER_ID_HERE";
-my $merchant_center_id           = "INSERT_MERCHANT_CENTER_ID_HERE";
+my $merchant_center_account_id   = "INSERT_MERCHANT_CENTER_ACCOUNT_ID_HERE";
 my $create_default_listing_group = undef;
 
 sub add_shopping_product_ad {
-  my ($api_client, $customer_id, $merchant_center_id,
+  my ($api_client, $customer_id, $merchant_center_account_id,
     $create_default_listing_group)
     = @_;
 
@@ -84,7 +84,7 @@ sub add_shopping_product_ad {
   # Create a standard shopping campaign.
   my $campaign_resource_name =
     add_standard_shopping_campaign($api_client, $customer_id,
-    $budget_resource_name, $merchant_center_id);
+    $budget_resource_name, $merchant_center_account_id);
 
   # Create a shopping product ad group.
   my $ad_group_resource_name =
@@ -138,8 +138,9 @@ sub add_campaign_budget {
 
 # Creates a new standard shopping campaign in the specified client account.
 sub add_standard_shopping_campaign {
-  my ($api_client, $customer_id, $budget_resource_name, $merchant_center_id) =
-    @_;
+  my ($api_client, $customer_id, $budget_resource_name,
+    $merchant_center_account_id)
+    = @_;
 
   # Create a standard shopping campaign.
   my $campaign = Google::Ads::GoogleAds::V3::Resources::Campaign->new({
@@ -149,7 +150,7 @@ sub add_standard_shopping_campaign {
       advertisingChannelType => SHOPPING,
       shoppingSetting =>
         Google::Ads::GoogleAds::V3::Resources::ShoppingSetting->new({
-          merchantId => $merchant_center_id,
+          merchantId => $merchant_center_account_id,
           # Set the sales country of products to include in the campaign.
           salesCountry => "US",
           # Set the priority of the campaign. Higher numbers take priority over
@@ -312,19 +313,17 @@ $api_client->set_die_on_faults(1);
 # Parameters passed on the command line will override any parameters set in code.
 GetOptions(
   "customer_id=s"                  => \$customer_id,
-  "merchant_center_id=i"           => \$merchant_center_id,
+  "merchant_center_account_id=i"   => \$merchant_center_account_id,
   "create_default_listing_group=s" => \$create_default_listing_group
 );
 
 # Print the help message if the parameters are not initialized in the code nor
 # in the command line.
-pod2usage(2) if not check_params($customer_id, $merchant_center_id);
+pod2usage(2) if not check_params($customer_id, $merchant_center_account_id);
 
 # Call the example.
-add_shopping_product_ad(
-  $api_client,         $customer_id =~ s/-//gr,
-  $merchant_center_id, $create_default_listing_group
-);
+add_shopping_product_ad($api_client, $customer_id =~ s/-//gr,
+  $merchant_center_account_id, $create_default_listing_group);
 
 =pod
 
@@ -348,7 +347,7 @@ add_shopping_product_ad.pl [options]
 
     -help                           Show the help message.
     -customer_id                    The Google Ads customer ID.
-    -merchant_center_id             The Merchant Center ID.
+    -merchant_center_account_id     The Merchant Center account ID.
     -create_default_listing_group   [optional] Create default listing group.
 
 =cut
